/*
  AUDIO extension
  (c) 2007 Helge Bahmann <hcb@chaoticmind.net>
  see the file COPYING for terms of redistribution
 */

#ifndef __X11_EXTENSIONS_XAUDIO_H
#define __X11_EXTENSIONS_XAUDIO_H

#include <X11/Xlib.h>
#include <X11/extensions/Xtime.h>
#include <X11/extensions/audio.h>
#include <stdint.h>

#ifdef __cplusplus
extern "C"
{
#endif

typedef uint32_t XaudioSampleBuffer;
typedef uint32_t XaudioPlaybackContext;
typedef uint32_t XaudioPCMDevice;
typedef uint32_t XaudioPCMContext;
typedef uint32_t XaudioShmSegment;

#define XaudioBadExtension -1

int XaudioQueryExtension(
	Display *dpy,
	unsigned int *version,
	unsigned int *revision,
	unsigned int *requestBase,
	unsigned int *eventBase,
	unsigned int *errorBase);

unsigned int XaudioQueryShmSampleFormat(
	Display *dpy);

XaudioShmSegment XaudioShmAttach(
	Display *dpy, int shmid, int readonly);

void XaudioShmDetach(
	Display *dpy, XaudioShmSegment shmseg);

XaudioSampleBuffer XaudioCreateSampleBuffer(
	Display *dpy,
	unsigned int size);

XaudioSampleBuffer XaudioCreateShmSampleBuffer(
	Display *dpy,
	unsigned int size, unsigned int space,
	XaudioShmSegment shmseg, unsigned int offset,
	unsigned int baseptr_offset);

XaudioSampleBuffer XaudioReferenceSampleBuffer(
	Display *dpy,
	XaudioSampleBuffer buffer);

void XaudioFreeSampleBuffer(
	Display *dpy,
	XaudioSampleBuffer buffer);

void XaudioPutSamples(
	Display *dpy,
	XaudioSampleBuffer buffer,
	unsigned int offset,
	const void *data,
	unsigned int nsamples,
	unsigned int format);

void XaudioGetSamples(
	Display *dpy,
	XaudioSampleBuffer buffer,
	unsigned int offset,
	void *data,
	unsigned int nsamples,
	unsigned int format);

void XaudioSampleBufferGetInfo(
	Display *dpy,
	XaudioSampleBuffer buffer,
	unsigned int *size,
	unsigned int *base);

void XaudioSampleBufferShiftBase(
	Display *dpy,
	XaudioSampleBuffer buffer,
	int offset);

void XtimeAudioSampleBufferShiftBase(
	XtimeGroup *group,
	XaudioSampleBuffer buffer,
	int offset);

void XaudioSampleBufferSetBase(
	Display *dpy,
	XaudioSampleBuffer buffer,
	int position);

void XtimeAudioSampleBufferSetBase(
	XtimeGroup *group,
	XaudioSampleBuffer buffer,
	int position);

void XaudioMultiplyConstant(
	Display *dpy,
	XaudioSampleBuffer dst, int dst_offset,
	XaudioSampleBuffer src, int src_offset,
	double constant,
	unsigned int count);

void XtimeAudioMultiplyConstant(
	XtimeGroup *group,
	XaudioSampleBuffer dst, int dst_offset,
	XaudioSampleBuffer src, int src_offset,
	double constant,
	unsigned int count);

void XaudioMultiplyConstantAccumulate(
	Display *dpy,
	XaudioSampleBuffer dst, int dst_offset,
	XaudioSampleBuffer src, int src_offset,
	double constant,
	unsigned int count);

void XtimeAudioMultiplyConstantAccumulate(
	XtimeGroup *group,
	XaudioSampleBuffer dst, int dst_offset,
	XaudioSampleBuffer src, int src_offset,
	double constant,
	unsigned int count);

void XaudioMultiply(
	Display *dpy,
	XaudioSampleBuffer dst, int dst_offset,
	XaudioSampleBuffer src1, int src1_offset,
	XaudioSampleBuffer src2, int src2_offset,
	unsigned int count);

void XtimeAudioMultiply(
	XtimeGroup *group,
	XaudioSampleBuffer dst, int dst_offset,
	XaudioSampleBuffer src1, int src1_offset,
	XaudioSampleBuffer src2, int src2_offset,
	unsigned int count);

void XaudioMultiplyAccumulate(
	Display *dpy,
	XaudioSampleBuffer dst, int dst_offset,
	XaudioSampleBuffer src1, int src1_offset,
	XaudioSampleBuffer src2, int src2_offset,
	unsigned int count);

void XtimeAudioMultiplyAccumulate(
	XtimeGroup *group,
	XaudioSampleBuffer dst, int dst_offset,
	XaudioSampleBuffer src1, int src1_offset,
	XaudioSampleBuffer src2, int src2_offset,
	unsigned int count);

void XaudioConvolute(
	Display *dpy,
	XaudioSampleBuffer dst, int dst_offset, unsigned int dst_count,
	XaudioSampleBuffer src, int src_offset, unsigned int src_count,
	XaudioSampleBuffer kern,
	int denominator, int shift,
	int scalesrc, int scaledst);

void XtimeAudioConvolute(
	XtimeGroup *group,
	XaudioSampleBuffer dst, int dst_offset, unsigned int dst_count,
	XaudioSampleBuffer src, int src_offset, unsigned int src_count,
	XaudioSampleBuffer kern,
	int denominator, int shift,
	int scalesrc, int scaledst);

void XaudioConvoluteAccumulate(
	Display *dpy,
	XaudioSampleBuffer dst, int dst_offset, unsigned int dst_count,
	XaudioSampleBuffer src, int src_offset, unsigned int src_count,
	XaudioSampleBuffer kern,
	int denominator, int shift,
	int scalesrc, int scaledst);

void XtimeAudioConvoluteAccumulate(
	XtimeGroup *group,
	XaudioSampleBuffer dst, int dst_offset, unsigned int dst_count,
	XaudioSampleBuffer src, int src_offset, unsigned int src_count,
	XaudioSampleBuffer kern,
	int denominator, int shift,
	int scalesrc, int scaledst);

int XaudioListPCMDevices(Display *dpy, XaudioPCMDevice **device_list);
XaudioPCMDevice XaudioQueryPCMDeviceType(Display *dpy, XaudioPCMDevice pcmdev,
	int *device_type);
XaudioPCMDevice XaudioGetDefaultPCMDevice(Display *dpy, Window root,
	int device_type);

int XaudioListPCMDeviceProperties(Display *dpy,
	XaudioPCMDevice device, Atom **properties, unsigned int *nproperties);
void XaudioSetPCMDeviceProperty(Display *dpy,
	XaudioPCMDevice device, Atom property,
	const void *value, unsigned int size);
int XaudioGetPCMDeviceProperty(Display *dpy,
	XaudioPCMDevice device, Atom property,
	void **value, unsigned int *size);
void XaudioDeletePCMDeviceProperty(Display *dpy,
	XaudioPCMDevice device, Atom property);


XaudioPCMContext XaudioCreatePCMContext(Display *dpy, XaudioPCMDevice pcmdev);
void XaudioFreePCMContext(Display *dpy, XaudioPCMContext ctx);
int XaudioQueryChannelLayoutRange(Display *dpy, XaudioPCMContext ctx,
	unsigned int *nlayouts, unsigned int **layouts);
int XaudioQuerySampleRateRange(Display *dpy, XaudioPCMContext ctx,
	unsigned int *nrate_stops, unsigned int **rate_stops);
unsigned int XaudioQueryMinimumLatency(Display *dpy, XaudioPCMContext ctx);
unsigned int XaudioQueryMinimumTimeResolution(Display *dpy, XaudioPCMContext ctx);
void XaudioSetChannelLayout(Display *dpy, XaudioPCMContext ctx,
	unsigned int layout);
void XaudioSetSampleRate(Display *dpy, XaudioPCMContext ctx,
	unsigned int rate);
void XaudioSetLatency(Display *dpy, XaudioPCMContext ctx,
	unsigned int latency);
void XaudioSetTimeResolution(Display *dpy, XaudioPCMContext ctx,
	unsigned int resolution);
int XaudioGetPCMContextConfiguration(Display *dpy, XaudioPCMContext ctx,
	unsigned int *channel_layout,
	unsigned int *sample_rate,
	unsigned int *latency,
	unsigned int *time_resolution,
	XaudioSampleBuffer **buffers,
	unsigned int **positions);
void XaudioAssignChannel(Display *dpy, XaudioPCMContext ctx,
	unsigned int channel, XaudioSampleBuffer buffer, int position);
void XaudioStart(Display *dpy, XaudioPCMContext ctx,
	int start_time, int end_time);
void XaudioStop(Display *dpy, XaudioPCMContext ctx);

XaudioPCMDevice XaudioCreateVirtualPCMDevice(Display *dpy, int type,
	unsigned int nchannel_layouts, const ChannelLayout layouts[],
	unsigned int nrate_stops, const unsigned int rate_stops[],
	unsigned int min_latency, unsigned int min_time_resolution);
void XaudioSetDefaultPCMDevice(Display *dpy, Window root,
	XaudioPCMDevice device);
void XaudioBindVirtualPCMContext(Display *dpy,
	XaudioPCMContext master, XaudioPCMContext slave,
	unsigned int rate_numerator, unsigned int rate_denominator,
	unsigned int master_offset, unsigned int slave_offset);
void XaudioDisconnectVirtualPCMContext(Display *dpy,
	XaudioPCMContext slave);

int XaudioListPCMContextProperties(Display *dpy,
	XaudioPCMContext context, Atom **properties, unsigned int *nproperties);
void XaudioSetPCMContextProperty(Display *dpy,
	XaudioPCMContext context, Atom property,
	const void *value, unsigned int size);
int XaudioGetPCMContextProperty(Display *dpy,
	XaudioPCMContext context, Atom property,
	void **value, unsigned int *size);
void XaudioDeletePCMContextProperty(Display *dpy,
	XaudioPCMContext context, Atom property);


typedef struct XaudioVirtualPCMEvent {
	int type;
	unsigned long serial;
	Bool send_event;
	Display *display;
	XaudioPCMDevice pcmdev;
	XaudioPCMContext context;
	uint32_t operation;
	uint32_t timestamp, timestamp2;
} XaudioVirtualPCMEvent;


#ifdef __cplusplus
}
#endif

#endif

