/*
  TIME extension
  (c) 2007 Helge Bahmann <hcb@chaoticmind.net>
  see the file COPYING for terms of redistribution
 */

#ifndef __X11_EXTENSIONS_XTIME
#define __X11_EXTENSIONS_XTIME

#include <X11/Xfuncproto.h>
#include <X11/Xlib.h>

#include <X11/extensions/time.h>

#include <stdint.h>

#ifdef __cplusplus
extern "C"
{
#endif

typedef uint32_t XtimeClock;
typedef uint32_t XtimeGroupID;
typedef uint32_t XtimeScheduler;

typedef struct _XtimeGroup XtimeGroup;

int XtimeQueryExtension(
	Display *dpy,
	unsigned int *version,
	unsigned int *revision,
	unsigned int *requestBase,
	unsigned int *eventBase,
	unsigned int *errorBase);

XtimeClock XtimeCreateClock(Display *dpy, unsigned int rate, uint32_t initial_value);
void XtimeFreeClock(Display *dpy, XtimeClock clock);

void XtimeStartClock(Display *dpy, XtimeClock clock);
void XtimeStopClock(Display *dpy, XtimeClock clock);

uint32_t XtimeClockGetTime(Display *dpy, XtimeClock clock);

XtimeScheduler XtimeCreateScheduler(Display *dpy, XtimeClock clock);
void XtimeFreeScheduler(Display *dpy, XtimeScheduler scheduler);

void XtimeScheduleGroup(Display *dpy, XtimeScheduler sched,
	XtimeGroupID group, uint32_t begin, uint32_t end,
	uint32_t flags,
	void *reqdata, uint32_t req_data_size);
void XtimeReplaceGroup(Display *dpy, XtimeScheduler sched,
	XtimeGroupID group,
	void *reqdata, uint32_t req_data_size);
void XtimeCancelGroup(Display *dpy, XtimeScheduler sched,
	XtimeGroupID group);

typedef struct XtimeTimerEvent {
	int type;
	unsigned long serial;
	Bool send_event;
	Display *display;
	XtimeScheduler scheduler;
	XtimeGroupID group;
	uint32_t timestamp;
	uint32_t status;
} XtimeTimerEvent;

XtimeGroup *XtimeBegin(Display *dpy, XtimeScheduler sched, 
	XtimeGroupID id, uint32_t begin, uint32_t end);
XtimeGroup *XtimeBeginReplace(Display *dpy, XtimeScheduler scheduler,
	XtimeGroupID id);
int XtimeGroupSetNotification(XtimeGroup *group, unsigned int notify);
int XtimeEnd(XtimeGroup *group);
void XtimeAbort(XtimeGroup *group);

void *_XtimeReserve(XtimeGroup *group, size_t size);
Display *_XtimeDisplayFromGroup(XtimeGroup *group);
void _XtimeGroupSetError(XtimeGroup *group, int error);

#ifdef __cplusplus
}
#endif

#endif
