/*
  AUDIO extension
  (c) 2007 Helge Bahmann <hcb@chaoticmind.net>
  see the file COPYING for terms of redistribution
 */

#ifndef __X11_EXTENSIONS_AUDIOPROTO
#define __X11_EXTENSIONS_AUDIOPROTO

#include <X11/Xmd.h>

/* requests and replies */

#define xaudio_QueryExtension 0
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
} xaudioQueryExtensionReq;
#define sz_xaudioQueryExtensionReq sizeof(xaudioQueryExtensionReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD16 version B16;
	CARD16 revision B16;
	CARD32 pad3 B32, pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioQueryExtensionReply;

#define xaudio_QueryShmSampleFormat 1
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
} xaudioQueryShmSampleFormatReq;
#define sz_xaudioQueryShmSampleFormatReq sizeof(xaudioQueryShmSampleFormatReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 format B32;
	CARD32 pad3 B32, pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioQueryShmSampleFormatReply;

#define xaudio_ShmAttach 2
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 id;
	CARD32 kernel_shmid;
	CARD32 readonly;
} xaudioShmAttachReq;
#define sz_xaudioShmAttachReq sizeof(xaudioShmAttachReq)

#define xaudio_ShmDetach 3
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 id;
} xaudioShmDetachReq;
#define sz_xaudioShmDetachReq sizeof(xaudioShmDetachReq)

#define xaudio_CreateSampleBuffer 16
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 bufferid;
	CARD32 size;
} xaudioCreateSampleBufferReq;
#define sz_xaudioCreateSampleBufferReq sizeof(xaudioCreateSampleBufferReq)

#define xaudio_FreeSampleBuffer 17
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 bufferid;
} xaudioFreeSampleBufferReq;
#define sz_xaudioFreeSampleBufferReq sizeof(xaudioFreeSampleBufferReq)

#define xaudio_PutSamples 18
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 bufferid;
	CARD32 offset;
	CARD32 numsamples;
	CARD32 format;
} xaudioPutSamplesReq;
#define sz_xaudioPutSamplesReq sizeof(xaudioPutSamplesReq)

#define xaudio_GetSamples 19
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 bufferid;
	CARD32 offset;
	CARD32 numsamples;
	CARD32 format;
} xaudioGetSamplesReq;
#define sz_xaudioGetSamplesReq sizeof(xaudioGetSamplesReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 numsamples B32;
	CARD32 format B32;
	CARD32 pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioGetSamplesReply;

#define xaudio_SampleBufferShiftBase 20
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 bufferid;
	INT32 offset;
} xaudioSampleBufferShiftBaseReq;
#define sz_xaudioSampleBufferShiftBaseReq sizeof(xaudioSampleBufferShiftBaseReq)

#define xaudio_SampleBufferSetBase 21
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 bufferid;
	CARD32 position;
} xaudioSampleBufferSetBaseReq;
#define sz_xaudioSampleBufferSetBaseReq sizeof(xaudioSampleBufferSetBaseReq)

#define xaudio_SampleBufferGetInfo 22
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 bufferid;
} xaudioSampleBufferGetInfoReq;
#define sz_xaudioSampleBufferGetInfoReq sizeof(xaudioSampleBufferGetInfoReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 base B32;
	CARD32 size B32;
	CARD32 pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioSampleBufferGetInfoReply;

#define xaudio_CreateShmSampleBuffer 23
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 bufferid;
	CARD32 size;
	CARD32 space;
	CARD32 offset;
	CARD32 baseptr_offset;
	CARD32 shmseg;
} xaudioCreateShmSampleBufferReq;
#define sz_xaudioCreateShmSampleBufferReq sizeof(xaudioCreateShmSampleBufferReq)

#define xaudio_MultiplyConstant 24
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 dst;
	CARD32 dst_offset;
	CARD32 src;
	CARD32 src_offset;
	INT32 constant; /* Fixed 16.16 format */
	CARD32 count;
} xaudioMultiplyConstantReq;
#define sz_xaudioMultiplyConstantReq sizeof(xaudioMultiplyConstantReq)

#define xaudio_MultiplyConstantAccumulate 25
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 dst;
	CARD32 dst_offset;
	CARD32 src;
	CARD32 src_offset;
	INT32 constant; /* Fixed 16.16 format */
	CARD32 count;
} xaudioMultiplyConstantAccumulateReq;
#define sz_xaudioMultiplyConstantAccumulateReq sizeof(xaudioMultiplyConstantAccumulateReq)

#define xaudio_Multiply 26
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 dst;
	CARD32 dst_offset;
	CARD32 src1;
	CARD32 src1_offset;
	CARD32 src2;
	CARD32 src2_offset;
	CARD32 count;
} xaudioMultiplyReq;
#define sz_xaudioMultiplyReq sizeof(xaudioMultiplyReq)

#define xaudio_MultiplyAccumulate 27
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 dst;
	CARD32 dst_offset;
	CARD32 src1;
	CARD32 src1_offset;
	CARD32 src2;
	CARD32 src2_offset;
	CARD32 count;
} xaudioMultiplyAccumulateReq;
#define sz_xaudioMultiplyAccumulateReq sizeof(xaudioMultiplyAccumulateReq)

#define xaudio_Convolute 28
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 dst;
	CARD32 dst_offset;
	CARD32 dst_count;
	CARD32 src;
	CARD32 src_offset;
	CARD32 src_count;
	CARD32 kern;
	CARD32 denominator;
	INT32 shift, scalesrc, scaledst;
} xaudioConvoluteReq;
#define sz_xaudioConvoluteReq sizeof(xaudioConvoluteReq)

#define xaudio_ConvoluteAccumulate 29
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 dst;
	CARD32 dst_offset;
	CARD32 dst_count;
	CARD32 src;
	CARD32 src_offset;
	CARD32 src_count;
	CARD32 kern;
	CARD32 denominator;
	INT32 shift, scalesrc, scaledst;
} xaudioConvoluteAccumulateReq;
#define sz_xaudioConvoluteAccumulateReq sizeof(xaudioConvoluteAccumulateReq)

#define xaudio_ConvoluteSymmetric 30
#define xaudio_ConvoluteSymmetricAccumulate 31

#define xaudio_Clamp 32
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 dst;
	CARD32 dst_offset;
	CARD32 src;
	CARD32 src_offset;
	INT32 low; /* Fixed 16.16 format */
	INT32 high; /* Fixed 16.16 format */
	CARD32 count;
} xaudioClampReq;
#define sz_xaudioClampReq sizeof(xaudioClampReq)

#define xaudio_ClampAccumulate 33
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 dst;
	CARD32 dst_offset;
	CARD32 src;
	CARD32 src_offset;
	CARD32 low;
	INT32 high; /* Fixed 16.16 format */
	INT32 count; /* Fixed 16.16 format */
} xaudioClampAccumulateReq;
#define sz_xaudioClampAccumulateReq sizeof(xaudioClampAccumulateReq)

#define xaudio_SynthLinear 40
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 dst;
	CARD32 offset;
	CARD32 count;
	INT32 value; /* Fixed 16.16 format */
	INT32 slope; /* Fixed 16.16 format */
} xaudioSynthLinearReq;
#define sz_xaudioSynthLinearReq sizeof(xaudioSynthLinearReq)

#define xaudio_ListPCMDevices 48
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
} xaudioListPCMDevicesReq;
#define sz_xaudioListPCMDevicesReq sizeof(xaudioListPCMDevicesReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 pad2 B32, pad3 B32, pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioListPCMDevicesReply;


#define xaudio_QueryPCMDeviceType 49
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 device;
} xaudioQueryPCMDeviceTypeReq;
#define sz_xaudioQueryPCMDeviceTypeReq sizeof(xaudioQueryPCMDeviceTypeReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 device B32;
	CARD32 deviceType B32;
	CARD32 pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioQueryPCMDeviceTypeReply;

#define xaudio_GetDefaultPCMDevice 50
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 window;
	CARD32 deviceType;
} xaudioGetDefaultPCMDeviceReq;
#define sz_xaudioGetDefaultPCMDeviceReq sizeof(xaudioGetDefaultPCMDeviceReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 device B32;
	CARD32 pad3 B32, pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioGetDefaultPCMDeviceReply;

#define xaudio_ListPCMDeviceProperties 51
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 device;
} xaudioListPCMDevicePropertiesReq;
#define sz_xaudioListPCMDevicePropertiesReq sizeof(xaudioListPCMDevicePropertiesReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 device B32;
	CARD32 pad3 B32, pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioListPCMDevicePropertiesReply;
	
#define xaudio_SetPCMDeviceProperty 52
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 device;
	CARD32 property;
	CARD32 property_length;
} xaudioSetPCMDevicePropertyReq;
#define sz_xaudioSetPCMDevicePropertyReq sizeof(xaudioSetPCMDevicePropertyReq)

#define xaudio_GetPCMDeviceProperty 53
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 device;
	CARD32 property;
} xaudioGetPCMDevicePropertyReq;
#define sz_xaudioGetPCMDevicePropertyReq sizeof(xaudioGetPCMDevicePropertyReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 device B32;
	CARD32 size B32;
	CARD32 pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioGetPCMDevicePropertyReply;
	
#define xaudio_DeletePCMDeviceProperty 54
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 device;
	CARD32 property;
} xaudioDeletePCMDevicePropertyReq;
#define sz_xaudioDeletePCMDevicePropertyReq sizeof(xaudioDeletePCMDevicePropertyReq)

#define xaudio_CreateVirtualPCMDevice 56
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 device_xid;
	CARD32 device_type;
	CARD32 nchannel_layouts;
	CARD32 nrate_stops;
	CARD32 min_latency;
	CARD32 min_time_resolution;
} xaudioCreateVirtualPCMDeviceReq;
#define sz_xaudioCreateVirtualPCMDeviceReq sizeof(xaudioCreateVirtualPCMDeviceReq)

#define xaudio_SetDefaultPCMDevice 57
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 window;
	CARD32 pcmdev;
} xaudioSetDefaultPCMDeviceReq;
#define sz_xaudioSetDefaultPCMDeviceReq sizeof(xaudioSetDefaultPCMDeviceReq)

#define xaudio_ReferenceSampleBuffer 58
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 old_id;
	CARD32 new_id;
} xaudioReferenceSampleBufferReq;
#define sz_xaudioReferenceSampleBufferReq sizeof(xaudioReferenceSampleBufferReq)

#define xaudio_CreatePCMContext 64
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
	CARD32 pcmdev B32;
} xaudioCreatePCMContextReq;
#define sz_xaudioCreatePCMContextReq sizeof(xaudioCreatePCMContextReq)

#define xaudio_FreePCMContext 65
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
} xaudioFreePCMContextReq;
#define sz_xaudioFreePCMContextReq sizeof(xaudioFreePCMContextReq)

#define xaudio_QueryChannelLayoutRange 66
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
} xaudioQueryChannelLayoutRangeReq;
#define sz_xaudioQueryChannelLayoutRangeReq sizeof(xaudioQueryChannelLayoutRangeReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 nlayouts B32;
	CARD32 pad3 B32, pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioQueryChannelLayoutRangeReply;

#define xaudio_QuerySampleRateRange 67
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
} xaudioQuerySampleRateRangeReq;
#define sz_xaudioQuerySampleRateRangeReq sizeof(xaudioQuerySampleRateRangeReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 nstops B32;
	CARD32 pad3 B32, pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioQuerySampleRateRangeReply;

#define xaudio_QueryMinimumLatency 68
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
} xaudioQueryMinimumLatencyReq;
#define sz_xaudioQueryMinimumLatencyReq sizeof(xaudioQueryMinimumLatencyReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 latency B32;
	CARD32 pad3 B32, pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioQueryMinimumLatencyReply;

#define xaudio_QueryMinimumTimeResolution 69
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
} xaudioQueryMinimumTimeResolutionReq;
#define sz_xaudioQueryMinimumTimeResolutionReq sizeof(xaudioQueryMinimumTimeResolutionReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 resolution B32;
	CARD32 pad3 B32, pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioQueryMinimumTimeResolutionReply;

#define xaudio_SetChannelLayout 70
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
	CARD32 layout B32;
} xaudioSetChannelLayoutReq;
#define sz_xaudioSetChannelLayoutReq sizeof(xaudioSetChannelLayoutReq)

#define xaudio_SetSampleRate 71
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
	CARD32 rate B32;
} xaudioSetSampleRateReq;
#define sz_xaudioSetSampleRateReq sizeof(xaudioSetSampleRateReq)

#define xaudio_SetLatency 72
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
	CARD32 latency B32;
} xaudioSetLatencyReq;
#define sz_xaudioSetLatencyReq sizeof(xaudioSetLatencyReq)

#define xaudio_SetTimeResolution 73
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
	CARD32 resolution B32;
} xaudioSetTimeResolutionReq;
#define sz_xaudioSetTimeResolutionReq sizeof(xaudioSetTimeResolutionReq)

#define xaudio_GetPCMContextConfiguration 74
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
} xaudioGetPCMContextConfigurationReq;
#define sz_xaudioGetPCMContextConfigurationReq sizeof(xaudioGetPCMContextConfigurationReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 channel_layout B32;
	CARD32 sample_rate B32;
	CARD32 latency B32;
	CARD32 time_resolution B32;
	CARD32 nchannels B32;
	CARD32 pad7 B32;
} xaudioGetPCMContextConfigurationReply;

#define xaudio_AssignChannel 75
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
	CARD32 channel B32;
	CARD32 samplebuffer B32;
	CARD32 position B32;
} xaudioAssignChannelReq;
#define sz_xaudioAssignChannelReq sizeof(xaudioAssignChannelReq)

#define xaudio_Start 76
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
	CARD32 start_time B32;
	CARD32 stop_time B32;
} xaudioStartReq;
#define sz_xaudioStartReq sizeof(xaudioStartReq)

#define xaudio_Stop 77
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 ctxid B32;
} xaudioStopReq;
#define sz_xaudioStopReq sizeof(xaudioStopReq)

#define xaudio_BindVirtualPCMContext 78
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 master;
	CARD32 slave;
	CARD32 numerator;
	CARD32 denominator;
	CARD32 master_offset;
	CARD32 slave_offset;
} xaudioBindVirtualPCMContextReq;
#define sz_xaudioBindVirtualPCMContextReq sizeof(xaudioBindVirtualPCMContextReq)

#define xaudio_DisconnectVirtualPCMContext 79
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 slave;
} xaudioDisconnectVirtualPCMContextReq;
#define sz_xaudioDisconnectVirtualPCMContextReq sizeof(xaudioDisconnectVirtualPCMContextReq)

#define xaudio_ListPCMContextProperties 80
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 context;
} xaudioListPCMContextPropertiesReq;
#define sz_xaudioListPCMContextPropertiesReq sizeof(xaudioListPCMContextPropertiesReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD32 length B32;
	CARD32 context B32;
	CARD32 pad3 B32, pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioListPCMContextPropertiesReply;
	
#define xaudio_SetPCMContextProperty 81
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 context;
	CARD32 property;
	CARD32 property_length;
} xaudioSetPCMContextPropertyReq;
#define sz_xaudioSetPCMContextPropertyReq sizeof(xaudioSetPCMContextPropertyReq)

#define xaudio_GetPCMContextProperty 82
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 context;
	CARD32 property;
} xaudioGetPCMContextPropertyReq;
#define sz_xaudioGetPCMContextPropertyReq sizeof(xaudioGetPCMContextPropertyReq)
typedef struct {
	BYTE type;
	CARD8 pad1;
	CARD16 seqNum B16;
	CARD16 length B32;
	CARD32 context B32;
	CARD32 size B32;
	CARD32 pad4 B32, pad5 B32, pad6 B32, pad7 B32;
} xaudioGetPCMContextPropertyReply;
	
#define xaudio_DeletePCMContextProperty 83
typedef struct {
	CARD8 reqType;
	CARD8 reqMinorType;
	CARD16 length;
	CARD32 context;
	CARD32 property;
} xaudioDeletePCMContextPropertyReq;
#define sz_xaudioDeletePCMContextPropertyReq sizeof(xaudioDeletePCMContextPropertyReq)

/* events */

#define Xaudio_NEVENTS 1

typedef struct {
	BYTE type;
	BYTE reason;
	CARD16 seqnum B16;
	CARD32 deviceid;
	CARD32 ctxid;
	CARD32 operation B32;
	CARD32 timestamp B32;
	CARD32 timestamp2 B32;
	CARD32 pad6 B32, pad7 B32;
} xaudioVirtualPCMEvent;

#define Xaudio_NERRORS 0

#endif
